@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.jasper.servlet;
 
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.net.URL;
+import java.util.HashMap;
+import java.util.Map;
 
+import javax.servlet.RequestDispatcher;
 import javax.servlet.Servlet;
 import javax.servlet.ServletConfig;
 import javax.servlet.ServletContext;
@@ -31,7 +32,6 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.jsp.tagext.TagInfo;
 
-import org.apache.AnnotationProcessor;
 import org.apache.jasper.JasperException;
 import org.apache.jasper.JspCompilationContext;
 import org.apache.jasper.Options;
@@ -39,9 +39,14 @@ import org.apache.jasper.compiler.ErrorDispatcher;
 import org.apache.jasper.compiler.JavacErrorDetail;
 import org.apache.jasper.compiler.JspRuntimeContext;
 import org.apache.jasper.compiler.Localizer;
+import org.apache.jasper.runtime.ExceptionUtils;
+import org.apache.jasper.runtime.InstanceManagerFactory;
 import org.apache.jasper.runtime.JspSourceDependent;
+import org.apache.jasper.util.FastRemovalDequeue;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
+import org.apache.tomcat.InstanceManager;
+import org.apache.tomcat.Jar;
 
 /**
  * The JSP engine (a.k.a Jasper).
@@ -61,64 +66,88 @@ import org.apache.juli.logging.LogFactory;
  * @author Tim Fennell
  */
 
+@SuppressWarnings("deprecation") // Have to support SingleThreadModel
 public class JspServletWrapper {
 
-    // Logger
-    private Log log = LogFactory.getLog(JspServletWrapper.class);
+    private static final Map<String,Long> ALWAYS_OUTDATED_DEPENDENCIES =
+            new HashMap<>();
 
-    private Servlet theServlet;
-    private String jspUri;
-    private Class servletClass;
-    private Class tagHandlerClass;
-    private JspCompilationContext ctxt;
+    static {
+        // If this is missing,
+        ALWAYS_OUTDATED_DEPENDENCIES.put("/WEB-INF/web.xml", Long.valueOf(-1));
+    }
+
+    // Logger
+    private final Log log = LogFactory.getLog(JspServletWrapper.class); // must not be static
+
+    private volatile Servlet theServlet;
+    private final String jspUri;
+    private volatile Class<?> tagHandlerClass;
+    private final JspCompilationContext ctxt;
     private long available = 0L;
-    private ServletConfig config;
-    private Options options;
-    private boolean firstTime = true;
-    /** Whether the servlet needs reloading on next access */
+    private final ServletConfig config;
+    private final Options options;
+    /*
+     * The servlet / tag file needs a compilation check on first access. Use a
+     * separate flag (rather then theServlet == null / tagHandlerClass == null
+     * as it avoids the potentially expensive isOutDated() calls in
+     * ctxt.compile() if there are multiple concurrent requests for the servlet
+     * / tag before the class has been loaded.
+     */
+    private volatile boolean mustCompile = true;
+    /* Whether the servlet/tag file needs reloading on next access */
     private volatile boolean reload = true;
-    private boolean isTagFile;
+    private final boolean isTagFile;
     private int tripCount;
     private JasperException compileException;
-    /** Timestamp of last time servlet resource was modified */
+    /* Timestamp of last time servlet resource was modified */
     private volatile long servletClassLastModifiedTime;
     private long lastModificationTest = 0L;
+    private long lastUsageTime = System.currentTimeMillis();
+    private FastRemovalDequeue<JspServletWrapper>.Entry unloadHandle;
+    private final boolean unloadAllowed;
+    private final boolean unloadByCount;
+    private final boolean unloadByIdle;
 
     /*
      * JspServletWrapper for JSP pages.
      */
-    public JspServletWrapper(ServletConfig config, Options options, String jspUri,
-                      boolean isErrorPage, JspRuntimeContext rctxt)
-            throws JasperException {
+    public JspServletWrapper(ServletConfig config, Options options,
+            String jspUri, JspRuntimeContext rctxt) {
 
-	this.isTagFile = false;
+        this.isTagFile = false;
         this.config = config;
         this.options = options;
         this.jspUri = jspUri;
-        ctxt = new JspCompilationContext(jspUri, isErrorPage, options,
-					 config.getServletContext(),
-					 this, rctxt);
+        unloadByCount = options.getMaxLoadedJsps() > 0 ? true : false;
+        unloadByIdle = options.getJspIdleTimeout() > 0 ? true : false;
+        unloadAllowed = unloadByCount || unloadByIdle ? true : false;
+        ctxt = new JspCompilationContext(jspUri, options,
+                                         config.getServletContext(),
+                                         this, rctxt);
     }
 
     /*
      * JspServletWrapper for tag files.
      */
     public JspServletWrapper(ServletContext servletContext,
-			     Options options,
-			     String tagFilePath,
-			     TagInfo tagInfo,
-			     JspRuntimeContext rctxt,
-			     URL tagFileJarUrl)
-	    throws JasperException {
+                             Options options,
+                             String tagFilePath,
+                             TagInfo tagInfo,
+                             JspRuntimeContext rctxt,
+                             Jar tagJar) {
 
-	this.isTagFile = true;
-        this.config = null;	// not used
+        this.isTagFile = true;
+        this.config = null;        // not used
         this.options = options;
-	this.jspUri = tagFilePath;
-	this.tripCount = 0;
+        this.jspUri = tagFilePath;
+        this.tripCount = 0;
+        unloadByCount = options.getMaxLoadedJsps() > 0 ? true : false;
+        unloadByIdle = options.getJspIdleTimeout() > 0 ? true : false;
+        unloadAllowed = unloadByCount || unloadByIdle ? true : false;
         ctxt = new JspCompilationContext(jspUri, tagInfo, options,
-					 servletContext, this, rctxt,
-					 tagFileJarUrl);
+                                         servletContext, this, rctxt,
+                                         tagJar);
     }
 
     public JspCompilationContext getJspEngineContext() {
@@ -129,41 +158,47 @@ public class JspServletWrapper {
         this.reload = reload;
     }
 
-    public Servlet getServlet()
-        throws ServletException, IOException, FileNotFoundException
-    {
-        // DCL on 'reload' requires that 'reload' be volatile
-        // (this also forces a read memory barrier, ensuring the
-        // new servlet object is read consistently)
-        if (reload) {
+    public boolean getReload() {
+        return reload;
+    }
+
+    private boolean getReloadInternal() {
+        return reload && !ctxt.getRuntimeContext().isCompileCheckInProgress();
+    }
+
+    public Servlet getServlet() throws ServletException {
+        /*
+         * DCL on 'reload' requires that 'reload' be volatile
+         * (this also forces a read memory barrier, ensuring the new servlet
+         * object is read consistently).
+         *
+         * When running in non development mode with a checkInterval it is
+         * possible (see BZ 62603) for a race condition to cause failures
+         * if a Servlet or tag is reloaded while a compile check is running
+         */
+        if (getReloadInternal() || theServlet == null) {
             synchronized (this) {
                 // Synchronizing on jsw enables simultaneous loading
                 // of different pages, but not the same page.
-                if (reload) {
+                if (getReloadInternal() || theServlet == null) {
                     // This is to maintain the original protocol.
                     destroy();
 
                     final Servlet servlet;
 
                     try {
-                        servletClass = ctxt.load();
-                        servlet = (Servlet) servletClass.newInstance();
-                        AnnotationProcessor annotationProcessor = (AnnotationProcessor) config.getServletContext().getAttribute(AnnotationProcessor.class.getName());
-                        if (annotationProcessor != null) {
-                           annotationProcessor.processAnnotations(servlet);
-                           annotationProcessor.postConstruct(servlet);
-                        }
-                    } catch (IllegalAccessException e) {
-                        throw new JasperException(e);
-                    } catch (InstantiationException e) {
-                        throw new JasperException(e);
+                        InstanceManager instanceManager = InstanceManagerFactory.getInstanceManager(config);
+                        servlet = (Servlet) instanceManager.newInstance(ctxt.getFQCN(), ctxt.getJspLoader());
                     } catch (Exception e) {
-                        throw new JasperException(e);
+                        Throwable t = ExceptionUtils
+                                .unwrapInvocationTargetException(e);
+                        ExceptionUtils.handleThrowable(t);
+                        throw new JasperException(t);
                     }
 
                     servlet.init(config);
 
-                    if (!firstTime) {
+                    if (theServlet != null) {
                         ctxt.getRuntimeContext().incrementJspReloadCount();
                     }
 
@@ -204,24 +239,35 @@ public class JspServletWrapper {
                 if (this.servletClassLastModifiedTime < lastModified) {
                     this.servletClassLastModifiedTime = lastModified;
                     reload = true;
+                    // Really need to unload the old class but can't do that. Do
+                    // the next best thing which is throw away the JspLoader so
+                    // a new loader will be created which will load the new
+                    // class.
+                    // TODO Are there inefficiencies between reload and the
+                    //      isOutDated() check?
+                    ctxt.clearJspLoader();
                 }
             }
         }
     }
 
     /**
-     * Compile (if needed) and load a tag file
+     * Compile (if needed) and load a tag file.
+     * @return the loaded class
+     * @throws JasperException Error compiling or loading tag file
      */
-    public Class loadTagFile() throws JasperException {
+    public Class<?> loadTagFile() throws JasperException {
 
         try {
             if (ctxt.isRemoved()) {
                 throw new FileNotFoundException(jspUri);
             }
-            if (options.getDevelopment() || firstTime ) {
+            if (options.getDevelopment() || mustCompile) {
                 synchronized (this) {
-                    firstTime = false;
-                    ctxt.compile();
+                    if (options.getDevelopment() || mustCompile) {
+                        ctxt.compile();
+                        mustCompile = false;
+                    }
                 }
             } else {
                 if (compileException != null) {
@@ -229,72 +275,97 @@ public class JspServletWrapper {
                 }
             }
 
-            if (reload) {
-                tagHandlerClass = ctxt.load();
-                reload = false;
+            if (getReloadInternal() || tagHandlerClass == null) {
+                synchronized (this) {
+                    if (getReloadInternal() || tagHandlerClass == null) {
+                        tagHandlerClass = ctxt.load();
+                        // Volatile 'reload' forces in order write of 'tagHandlerClass'
+                        reload = false;
+                    }
+                }
             }
         } catch (FileNotFoundException ex) {
             throw new JasperException(ex);
-	}
+        }
 
-	return tagHandlerClass;
+        return tagHandlerClass;
     }
 
     /**
      * Compile and load a prototype for the Tag file.  This is needed
-     * when compiling tag files with circular dependencies.  A prototpe
+     * when compiling tag files with circular dependencies.  A prototype
      * (skeleton) with no dependencies on other other tag files is
      * generated and compiled.
+     * @return the loaded class
+     * @throws JasperException Error compiling or loading tag file
      */
-    public Class loadTagFilePrototype() throws JasperException {
+    public Class<?> loadTagFilePrototype() throws JasperException {
 
-	ctxt.setPrototypeMode(true);
-	try {
-	    return loadTagFile();
-	} finally {
-	    ctxt.setPrototypeMode(false);
-	}
+        ctxt.setPrototypeMode(true);
+        try {
+            return loadTagFile();
+        } finally {
+            ctxt.setPrototypeMode(false);
+        }
     }
 
     /**
      * Get a list of files that the current page has source dependency on.
+     * @return the map of dependent resources
      */
-    public java.util.List getDependants() {
+    public java.util.Map<String,Long> getDependants() {
         try {
             Object target;
             if (isTagFile) {
                 if (reload) {
-                    tagHandlerClass = ctxt.load();
-                    reload = false;
+                    synchronized (this) {
+                        if (reload) {
+                            tagHandlerClass = ctxt.load();
+                            reload = false;
+                        }
+                    }
                 }
-                target = tagHandlerClass.newInstance();
+                target = tagHandlerClass.getConstructor().newInstance();
             } else {
                 target = getServlet();
             }
-            if (target != null && target instanceof JspSourceDependent) {
-                return ((java.util.List) ((JspSourceDependent) target).getDependants());
+            if (target instanceof JspSourceDependent) {
+                return ((JspSourceDependent) target).getDependants();
             }
+        } catch (AbstractMethodError ame) {
+            // Almost certainly a pre Tomcat 7.0.17 compiled JSP using the old
+            // version of the interface. Force a re-compile.
+            return ALWAYS_OUTDATED_DEPENDENCIES;
         } catch (Throwable ex) {
+            ExceptionUtils.handleThrowable(ex);
         }
         return null;
     }
 
     public boolean isTagFile() {
-	return this.isTagFile;
+        return this.isTagFile;
     }
 
     public int incTripCount() {
-	return tripCount++;
+        return tripCount++;
     }
 
     public int decTripCount() {
-	return tripCount--;
+        return tripCount--;
+    }
+
+    public String getJspUri() {
+        return jspUri;
+    }
+
+    public FastRemovalDequeue<JspServletWrapper>.Entry getUnloadHandle() {
+        return unloadHandle;
     }
 
     public void service(HttpServletRequest request,
                         HttpServletResponse response,
                         boolean precompile)
-	    throws ServletException, IOException, FileNotFoundException {
+            throws ServletException, IOException, FileNotFoundException {
 
         Servlet servlet;
 
@@ -311,21 +382,22 @@ public class JspServletWrapper {
                         (HttpServletResponse.SC_SERVICE_UNAVAILABLE,
                          Localizer.getMessage("jsp.error.unavailable"));
                     return;
-                } else {
-                    // Wait period has expired. Reset.
-                    available = 0;
                 }
+
+                // Wait period has expired. Reset.
+                available = 0;
             }
 
             /*
              * (1) Compile
              */
-            if (options.getDevelopment() || firstTime ) {
+            if (options.getDevelopment() || mustCompile) {
                 synchronized (this) {
-                    firstTime = false;
-
-                    // The following sets reload to true, if necessary
-                    ctxt.compile();
+                    if (options.getDevelopment() || mustCompile) {
+                        // The following sets reload to true, if necessary
+                        ctxt.compile();
+                        mustCompile = false;
+                    }
                 }
             } else {
                 if (compileException != null) {
@@ -344,39 +416,44 @@ public class JspServletWrapper {
                 return;
             }
 
-        } catch (ServletException ex) {
-            if (options.getDevelopment()) {
-                throw handleJspException(ex);
-            } else {
-                throw ex;
-            }
         } catch (FileNotFoundException fnfe) {
             // File has been removed. Let caller handle this.
             throw fnfe;
-        } catch (IOException ex) {
+        } catch (ServletException | IOException | IllegalStateException ex) {
             if (options.getDevelopment()) {
                 throw handleJspException(ex);
-            } else {
-                throw ex;
-            }
-        } catch (IllegalStateException ex) {
-            if (options.getDevelopment()) {
-                throw handleJspException(ex);
-            } else {
-                throw ex;
             }
+            throw ex;
         } catch (Exception ex) {
             if (options.getDevelopment()) {
                 throw handleJspException(ex);
-            } else {
-                throw new JasperException(ex);
             }
+            throw new JasperException(ex);
         }
 
         try {
+            /*
+             * (3) Handle limitation of number of loaded Jsps
+             */
+            if (unloadAllowed) {
+                synchronized(this) {
+                    if (unloadByCount) {
+                        if (unloadHandle == null) {
+                            unloadHandle = ctxt.getRuntimeContext().push(this);
+                        } else if (lastUsageTime < ctxt.getRuntimeContext().getLastJspQueueUpdate()) {
+                            ctxt.getRuntimeContext().makeYoungest(unloadHandle);
+                            lastUsageTime = System.currentTimeMillis();
+                        }
+                    } else {
+                        if (lastUsageTime < ctxt.getRuntimeContext().getLastJspQueueUpdate()) {
+                            lastUsageTime = System.currentTimeMillis();
+                        }
+                    }
+                }
+            }
 
             /*
-             * (3) Service request
+             * (4) Service request
              */
             if (servlet instanceof SingleThreadModel) {
                // sync on the wrapper so that the freshness
@@ -387,50 +464,40 @@ public class JspServletWrapper {
             } else {
                 servlet.service(request, response);
             }
-
         } catch (UnavailableException ex) {
             String includeRequestUri = (String)
-                request.getAttribute("javax.servlet.include.request_uri");
+                request.getAttribute(RequestDispatcher.INCLUDE_REQUEST_URI);
             if (includeRequestUri != null) {
                 // This file was included. Throw an exception as
                 // a response.sendError() will be ignored by the
                 // servlet engine.
                 throw ex;
-            } else {
-                int unavailableSeconds = ex.getUnavailableSeconds();
-                if (unavailableSeconds <= 0) {
-                    unavailableSeconds = 60;        // Arbitrary default
-                }
-                available = System.currentTimeMillis() +
-                    (unavailableSeconds * 1000L);
-                response.sendError
-                    (HttpServletResponse.SC_SERVICE_UNAVAILABLE,
-                     ex.getMessage());
             }
-        } catch (ServletException ex) {
+
+            int unavailableSeconds = ex.getUnavailableSeconds();
+            if (unavailableSeconds <= 0) {
+                unavailableSeconds = 60;        // Arbitrary default
+            }
+            available = System.currentTimeMillis() +
+                (unavailableSeconds * 1000L);
+            response.sendError
+                (HttpServletResponse.SC_SERVICE_UNAVAILABLE,
+                 ex.getMessage());
+        } catch (ServletException | IllegalStateException ex) {
             if(options.getDevelopment()) {
                 throw handleJspException(ex);
-            } else {
-                throw ex;
             }
+            throw ex;
         } catch (IOException ex) {
-            if(options.getDevelopment()) {
-                throw handleJspException(ex);
-            } else {
-                throw ex;
-            }
-        } catch (IllegalStateException ex) {
-            if(options.getDevelopment()) {
-                throw handleJspException(ex);
-            } else {
-                throw ex;
+            if (options.getDevelopment()) {
+                throw new IOException(handleJspException(ex).getMessage(), ex);
             }
+            throw ex;
         } catch (Exception ex) {
             if(options.getDevelopment()) {
                 throw handleJspException(ex);
-            } else {
-                throw new JasperException(ex);
             }
+            throw new JasperException(ex);
         }
     }
 
@@ -439,17 +506,18 @@ public class JspServletWrapper {
             try {
                 theServlet.destroy();
             } catch (Throwable t) {
+                ExceptionUtils.handleThrowable(t);
                 log.error(Localizer.getMessage("jsp.error.servlet.destroy.failed"), t);
             }
-            AnnotationProcessor annotationProcessor = (AnnotationProcessor) config.getServletContext().getAttribute(AnnotationProcessor.class.getName());
-            if (annotationProcessor != null) {
-                try {
-                    annotationProcessor.preDestroy(theServlet);
-                } catch (Exception e) {
-                    // Log any exception, since it can't be passed along
-                    log.error(Localizer.getMessage("jsp.error.file.not.found",
-                           e.getMessage()), e);
-                }
+            InstanceManager instanceManager = InstanceManagerFactory.getInstanceManager(config);
+            try {
+                instanceManager.destroyInstance(theServlet);
+            } catch (Exception e) {
+                Throwable t = ExceptionUtils.unwrapInvocationTargetException(e);
+                ExceptionUtils.handleThrowable(t);
+                // Log any exception, since it can't be passed along
+                log.error(Localizer.getMessage("jsp.error.file.not.found",
+                        e.getMessage()), t);
             }
         }
     }
@@ -467,15 +535,22 @@ public class JspServletWrapper {
         this.lastModificationTest = lastModificationTest;
     }
 
+    /**
+     * @return the lastUsageTime.
+     */
+    public long getLastUsageTime() {
+        return lastUsageTime;
+    }
+
     /**
      * <p>Attempts to construct a JasperException that contains helpful information
      * about what went wrong. Uses the JSP compiler system to translate the line
      * number in the generated servlet that originated the exception to a line
      * number in the JSP.  Then constructs an exception containing that
      * information, and a snippet of the JSP to help debugging.
-     * Please see http://bz.apache.org/bugzilla/show_bug.cgi?id=37062 and
+     * Please see https://bz.apache.org/bugzilla/show_bug.cgi?id=37062 and
      * http://www.tfenne.com/jasper/ for more details.
-     *</p>
+     * </p>
      *
      * @param ex the exception that was the cause of the problem.
      * @return a JasperException with more detailed information
@@ -498,6 +573,7 @@ public class JspServletWrapper {
                 }
             }
 
+
             if (jspFrame == null ||
                     this.ctxt.getCompiler().getPageNodes() == null) {
                 // If we couldn't find a frame in the stack trace corresponding
@@ -505,43 +581,41 @@ public class JspServletWrapper {
                 // parsed JSP to hand, we can't really add anything
                 return new JasperException(ex);
             }
-            else {
-                int javaLineNumber = jspFrame.getLineNumber();
-                JavacErrorDetail detail = ErrorDispatcher.createJavacError(
-                        jspFrame.getMethodName(),
-                        this.ctxt.getCompiler().getPageNodes(),
-                        null,
-                        javaLineNumber,
-                        ctxt);
 
-                // If the line number is less than one we couldn't find out
-                // where in the JSP things went wrong
-                int jspLineNumber = detail.getJspBeginLineNumber();
-                if (jspLineNumber < 1) {
-                    throw new JasperException(ex);
-                }
+            int javaLineNumber = jspFrame.getLineNumber();
+            JavacErrorDetail detail = ErrorDispatcher.createJavacError(
+                    jspFrame.getMethodName(),
+                    this.ctxt.getCompiler().getPageNodes(),
+                    null,
+                    javaLineNumber,
+                    ctxt);
 
-                if (options.getDisplaySourceFragment()) {
-                    return new JasperException(Localizer.getMessage
-                            ("jsp.exception", detail.getJspFileName(),
-                                    "" + jspLineNumber) +
-                                    "\n\n" + detail.getJspExtract() +
-                                    "\n\nStacktrace:", ex);
-
-                } else {
-                    return new JasperException(Localizer.getMessage
-                            ("jsp.exception", detail.getJspFileName(),
-                                    "" + jspLineNumber), ex);
-                }
+            // If the line number is less than one we couldn't find out
+            // where in the JSP things went wrong
+            int jspLineNumber = detail.getJspBeginLineNumber();
+            if (jspLineNumber < 1) {
+                throw new JasperException(ex);
             }
+
+            if (options.getDisplaySourceFragment()) {
+                return new JasperException(Localizer.getMessage
+                        ("jsp.exception", detail.getJspFileName(),
+                                "" + jspLineNumber) + System.lineSeparator() +
+                                System.lineSeparator() + detail.getJspExtract() +
+                                System.lineSeparator() + System.lineSeparator() +
+                                "Stacktrace:", ex);
+
+            }
+
+            return new JasperException(Localizer.getMessage
+                    ("jsp.exception", detail.getJspFileName(),
+                            "" + jspLineNumber), ex);
         } catch (Exception je) {
             // If anything goes wrong, just revert to the original behaviour
             if (ex instanceof JasperException) {
                 return (JasperException) ex;
-            } else {
-                return new JasperException(ex);
             }
+            return new JasperException(ex);
         }
     }
-
 }
