@@ -51,6 +51,7 @@ public class HttpParser {
     private static final boolean[] IS_HTTP_PROTOCOL = new boolean[ARRAY_SIZE];
     private static final boolean[] IS_ALPHA = new boolean[ARRAY_SIZE];
     private static final boolean[] IS_NUMERIC = new boolean[ARRAY_SIZE];
+    private static final boolean[] IS_SCHEME = new boolean[ARRAY_SIZE];
     private static final boolean[] REQUEST_TARGET_ALLOW = new boolean[ARRAY_SIZE];
     private static final boolean[] IS_UNRESERVED = new boolean[ARRAY_SIZE];
     private static final boolean[] IS_SUBDELIM = new boolean[ARRAY_SIZE];
@@ -99,6 +100,10 @@ public class HttpParser {
                 IS_ALPHA[i] = true;
             }
 
+            if (IS_ALPHA[i] || IS_NUMERIC[i] || i == '+' || i == '-' || i == '.') {
+                IS_SCHEME[i] = true;
+            }
+
             if (IS_ALPHA[i] || IS_NUMERIC[i] || i == '-' || i == '.' || i == '_' || i == '~') {
                 IS_UNRESERVED[i] = true;
             }
@@ -238,6 +243,11 @@ public class HttpParser {
             char c = input.charAt(i);
             if (input.charAt(i) == '\\') {
                 i++;
+                if (i == end) {
+                    // Input (less surrounding quotes) ended with '\'. That is
+                    // invalid so return null.
+                    return null;
+                }
                 result.append(input.charAt(i));
             } else {
                 result.append(c);
@@ -334,6 +344,52 @@ public class HttpParser {
     }
 
 
+    public static boolean isScheme(int c) {
+        // Fast for valid scheme characters, slower for some incorrect
+        // ones
+        try {
+            return IS_SCHEME[c];
+        } catch (ArrayIndexOutOfBoundsException ex) {
+            return false;
+        }
+    }
+
+
+    /**
+     * Is the provided String a scheme as per RFC 3986?
+     * <br>
+     * Note: scheme = ALPHA *( ALPHA / DIGIT / "+" / "-" / "." )
+     * <br>
+     * Since a scheme requires at least 1 ALPHA, {@code null} and the empty
+     * string ({@code ""}) are not considered to be valid tokens.
+     *
+     * @param s The string to test
+     *
+     * @return {@code true} if the string is a valid scheme, otherwise
+     *         {@code false}
+     */
+    public static boolean isScheme(String s) {
+        if (s == null) {
+            return false;
+        }
+        if (s.isEmpty()) {
+            return false;
+        }
+        char[] chars = s.toCharArray();
+        if (!isAlpha(chars[0])) {
+            return false;
+        }
+        if (chars.length > 1) {
+            for (int i = 1; i < chars.length; i++) {
+                if (!isScheme(chars[i])) {
+                    return false;
+                }
+            }
+        }
+        return true;
+    }
+
+
     public static boolean isUserInfo(int c) {
         // Fast for valid user info characters, slower for some incorrect
         // ones
@@ -769,6 +825,10 @@ public class HttpParser {
                     }
                 } else {
                     octet = octet * 10 + c - '0';
+                    // Avoid overflow
+                    if (octet > 255) {
+                        break;
+                    }
                 }
             } else if (c == ':') {
                 break;
@@ -990,7 +1050,7 @@ public class HttpParser {
         private final boolean allowsEnd;
         private final String errorMsg;
 
-        private DomainParseState(boolean mayContinue, boolean allowsHyphen, boolean allowsPeriod,
+        DomainParseState(boolean mayContinue, boolean allowsHyphen, boolean allowsPeriod,
                 boolean allowsEnd, String errorMsg) {
             this.mayContinue = mayContinue;
             this.allowsHyphen = allowsHyphen;
